==> pointpos_api-0.2.0.tar.gz: test/loyalty_program_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for LoyaltyProgram
void main() {
  var instance = new LoyaltyProgram();

  group('test LoyaltyProgram', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // LoyaltyProgramPointFromTotalSpent pointFromTotalSpent (default value: null)
    test('to test the property `pointFromTotalSpent`', () async {
      // TODO
    });

    // LoyaltyProgramPointFromBuyItem pointFromBuyItem (default value: null)
    test('to test the property `pointFromBuyItem`', () async {
      // TODO
    });

    // num newMemberPoint (default value: null)
    test('to test the property `newMemberPoint`', () async {
      // TODO
    });

    // List<LoyaltyProgramRedeemRules> redeemRules (default value: const [])
    test('to test the property `redeemRules`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: null)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}

==> pointpos_api-0.2.1.tar.gz: test/loyalty_program_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for LoyaltyProgram
void main() {
  var instance = new LoyaltyProgram();

  group('test LoyaltyProgram', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // LoyaltyProgramPointFromTotalSpent pointFromTotalSpent (default value: null)
    test('to test the property `pointFromTotalSpent`', () async {
      // TODO
    });

    // LoyaltyProgramPointFromBuyItem pointFromBuyItem (default value: null)
    test('to test the property `pointFromBuyItem`', () async {
      // TODO
    });

    // num newMemberPoint (default value: null)
    test('to test the property `newMemberPoint`', () async {
      // TODO
    });

    // List<LoyaltyProgramRedeemRules> redeemRules (default value: const [])
    test('to test the property `redeemRules`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: false)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}
